"""
Test Poi CSV export.
"""

import io
import csv

import unittest

from zope import interface

from retrans.poi import interfaces
from retrans.poi import testing


class TestPoiCSVExport(unittest.TestCase):
    """
    Test Poi CSV export.
    """

    layer = testing.RETRANS_POI_ISSUE_INTEGRATION_TESTING

    def test_export_empty_issue(self):
        """
        An empty issue can be exported to CSV.
        """
        tracker = self.layer['tracker']
        interface.alsoProvides(tracker.REQUEST, interfaces.IRetransPoiLayer)

        exporter = tracker.unrestrictedTraverse('@@poi-issue-export')
        raw_csv = exporter()
        reader = csv.DictReader(io.BytesIO(raw_csv))
        rows = list(reader)

        self.assertEquals(
            len(rows), 1,
            'Wrong number of exported CSV rows')
        row = rows[0]
        self.assertIn(
            'Complexity', row,
            'Exported CSV missing custom issue field')
        self.assertEqual(
            row['Complexity'], '',
            'Exported CSV wrong custom issue field value')

        self.assertNotIn(
            'Software Engineer Time', row,
            'Exported CSV includes ambiguous custom issue field label')
        self.assertIn(
            'Software Engineer - Estimated', row,
            'Exported CSV missing custom issue field')
        self.assertIn(
            'System Engineer - Actual', row,
            'Exported CSV missing custom issue field')

        self.assertIn(
            'Operations ROI - Estimated', row,
            'Exported CSV missing custom issue field')
